<?php
/**
 * Provide a admin area view for the plugin
 *
 * This file is used to markup the admin-facing aspects of the plugin.
 *
 * @link       http://estatebud.com
 * @since      1.0.0
 *
 * @package    Estatebud
 * @subpackage Estatebud/admin/partials
 */

if (!isset($estatebud_api)) return;

if (isset($_POST['estatebud_property_page_id'])) {
    $estatebud_property_page_id = sanitize_text_field($_POST['estatebud_property_page_id']);
    update_option('estatebud_property_page_id', $estatebud_property_page_id);
    if(isset($_POST["estatebud_disable_fancybox"])){
        $estatebud_disable_fancybox = true;
        update_option("estatebud_disable_fancybox", true);
    }else{
        $estatebud_disable_fancybox = false;
        update_option("estatebud_disable_fancybox", false);
    }
} else {
    $estatebud_property_page_id = get_option("estatebud_property_page_id", "");
    $estatebud_disable_fancybox = get_option("estatebud_disable_fancybox", "");
}

if (isset($_POST['estatebud_theme_color'])) {
    $estatebud_theme_color = sanitize_hex_color($_POST['estatebud_theme_color']);
    update_option('estatebud_theme_color', $estatebud_theme_color);

} else {
    $estatebud_theme_color = esc_attr(get_option("estatebud_theme_color", "#7633e3"));
}

if (isset($_POST['estatebud_placeholder_image'])) {
    $estatebud_placeholder_image = esc_url_raw($_POST['estatebud_placeholder_image']);
    update_option('estatebud_placeholder_image', $estatebud_placeholder_image);
} else {
    $estatebud_placeholder_image = get_option("estatebud_placeholder_image", plugin_dir_url(__FILE__) . "../assets/placeholder.png");
}

if(isset($_POST['estatebud_custom_css'])){
    $custom_css = sanitize_textarea_field( $_POST["estatebud_custom_css"] );
    update_option('estatebud_custom_css', $custom_css);
}else{
    $custom_css = get_option('estatebud_custom_css', "");
}

?>
<form method="post">
    <style>
        .form-table tr th, .form-table tr td{
            vertical-align: top;
            padding: 20px 10px 20px 0px !important;
        }
    </style>
    <table class="form-table">
        <tr valign="top">
            <th scope="row"><?php _e("Estatebud Property Details Page", "estatebud");?></th>
            <td>
                <select name="estatebud_property_page_id" class="estatebud-api-key-input">
                    <option value=""><?php echo __( 'Select page' , "estatebud" ); ?></option>
                    <?php
                        $pages = get_pages();
                        foreach ( $pages as $page ) {
                            $option = '<option value="' . esc_attr($page->post_name) . '"';
                            if($page->post_name == $estatebud_property_page_id) $option .= "selected";
                            $option .= '>';
	                        $option .= $page->post_title;
	                        $option .= '</option>';
	                        echo $option;
                        }
                    ?>
                </select>
            </td>
        </tr>
        <tr valign="top">
            <th scope="row"><?php _e("Theme Color", "estatebud");?></th>
            <td>
                <input type="text" name="estatebud_theme_color" class="color-picker" value="<?php echo esc_attr( $estatebud_theme_color );?>" data-default-color="#7633e3" />
            </td>
        </tr>
        <tr valign="top">
            <th scope="row"><?php _e("Disable fancybox", "estatebud");?></th>
            <td>
                <input type="checkbox" name="estatebud_disable_fancybox" <?php echo $estatebud_disable_fancybox ? "checked" : ""; ?> />
                <p class="description"><?php _e("Disable fancybox enqueueing when already enqueued by other plugins/theme.", "estatebud");?></p>
            </td>
        </tr>
        <tr valign="top">
            <?php wp_enqueue_media(); ?>
            <th scope="row"><?php _e("Placeholder Image", "estatebud");?></th>
            <td>
            <div class='image-preview-wrapper'>
                <img id='image-preview' src='<?php echo esc_url( $estatebud_placeholder_image );?>' style='max-height: 150px;'>
            </div>
            <input id="upload_image_button" type="button" class="button" value="<?php _e( 'Upload image', "estatebud" ); ?>" />
            <input type='hidden' name='estatebud_placeholder_image' id='image_attachment_id' value='<?php echo esc_attr($estatebud_placeholder_image);?>'>
            </td>
        </tr>
        <tr valign="top">
            <th scope="row"><?php _e("Custom CSS", "estatebud");?> </th>
            <td>
            <div id="estatebud_custom_css_container">
                <div name="estatebud_custom_css" id="estatebud_custom_css" style="border: 1px solid #DFDFDF; -moz-border-radius: 3px; -webkit-border-radius: 3px; border-radius: 3px; width: 100%; height: 400px; position: relative;"></div>
            </div>
             <textarea id="estatebud_custom_css_textarea" name="estatebud_custom_css" style="display: none;"><?php echo $custom_css; ?></textarea>
            </td>
        </tr>
        <tr><th scope="row">&nbsp;</th><td><?php submit_button(); ?></td></tr>
    </table>
</form>
<script type='text/javascript'>
    jQuery( document ).ready( function( $ ) {
        // Uploading files
        var file_frame;
        var wp_media_post_id = wp.media.model.settings.post.id; // Store the old id
        var set_to_post_id = 0; // Set this
        jQuery('#upload_image_button').on('click', function( event ){
            event.preventDefault();
            // If the media frame already exists, reopen it.
            if ( file_frame ) {
                // Set the post ID to what we want
                file_frame.uploader.uploader.param( 'post_id', set_to_post_id );
                // Open frame
                file_frame.open();
                return;
            } else {
                // Set the wp.media post id so the uploader grabs the ID we want when initialised
                wp.media.model.settings.post.id = set_to_post_id;
            }
            // Create the media frame.
            file_frame = wp.media.frames.file_frame = wp.media({
                title: '<?php _e("Select a image to upload", "estatebud");?>',
                button: {
                    text: '<?php _e("Use this image", "estatebud");?>',
                },
                multiple: false	// Set to true to allow multiple files to be selected
            });
            // When an image is selected, run a callback.
            file_frame.on( 'select', function() {
                // We set multiple to false so only get one image from the uploader
                attachment = file_frame.state().get('selection').first().toJSON();
                // Do something with attachment.id and/or attachment.url here
                $( '#image-preview' ).attr( 'src', attachment.url ).css( 'width', 'auto' );
                $( '#image_attachment_id' ).val( attachment.url );
                // Restore the main post ID
                wp.media.model.settings.post.id = wp_media_post_id;
            });
                // Finally, open the modal
                file_frame.open();
        });
        // Restore the main ID when the add media button is pressed
        jQuery( 'a.add_media' ).on( 'click', function() {
            wp.media.model.settings.post.id = wp_media_post_id;
        });
    });
</script>