<?php

class Estatebud_Search_Widget extends WP_Widget
{
    private $version = "1.0.0";

    function __construct()
    {
        parent::__construct(
            'estatebud-search-widget',  // Base ID
            __("Estatebud Search Widget", "estatebud")   // Name
        );
        add_action('widgets_init', function () {
            register_widget('Estatebud_Search_Widget');
        });

        add_action('wp_enqueue_scripts', array($this, 'scripts'));
    }

    public $args = array(
        'before_title' => '<h4 class="widgettitle">',
        'after_title' => '</h4>',
        'before_widget' => '<div class="widget-wrap">',
        'after_widget' => '</div></div>'
    );

    public function scripts(){
        if(wp_script_is("estatebud-select") == false){
            wp_enqueue_style("estatebud-select", plugin_dir_url(__FILE__) . '../public/css/select2.css', array(), $this->version, 'all');
            wp_enqueue_style("estatebud-override", plugin_dir_url(__FILE__) . '../public/css/estatebud-select2.css', array(), $this->version, 'all');
            wp_enqueue_script("estatebud-select", plugin_dir_url(__FILE__) . '../public/js/select2.full.min.js', array('jquery'), $this->version, false);
        }
        wp_localize_script("estatebud", 'estatebudL10n', array(
            'select2_empty' => __("Nothing Selected", "estatebud"),
            'select2_format' => __("Selected {count} of {total} items", "estatebud"),
            'show_less' => __("Show Less", "estatebud"),
            'show_more' => __("Show More", "estatebud")
        ));
    }

    public function widget($args, $instance)
    {

        echo $args['before_widget'];

        if(isset($instance["searchbox"])){
            $items = get_option("estatebud_widget_settings", false);
            $estatebud_api = new EstatebudAPI(get_option("estatebud_api_key", null), isset($_GET["lang"]) ? $_GET["lang"] : get_locale());
            $request = [];

            if($items && $items[$instance["searchbox"]]){
                $item = $items[$instance["searchbox"]];
                $widget_template = stripslashes($item["template"]);
                $widget_template = preg_replace_callback('/\$\{([^}]+)\}\$/m', function($match){
                    return __($match[1], "estatebud");
                }, $widget_template);
                $widget_template = preg_replace_callback('/%(\w+)%/', function($match) use($estatebud_api, $request){
                    ob_start();
                    ob_implicit_flush(false);
                    switch($match[1]){
                        case "category_select":
                            include dirname(__FILE__) . "/../public/partials/inputs/estatebud-category-select.php";
                            break;
                        case "type_select":
                            include dirname(__FILE__) . "/../public/partials/inputs/estatebud-type-select.php";
                            break;
                        case "area_select":
                            include  dirname(__FILE__) . "/../public/partials/inputs/estatebud-area-select.php";
                            break;
                        case "condition_select":
                            include dirname(__FILE__) . "/../public/partials/inputs/estatebud-status-select.php";
                            break;
                        case "bedroom_select":
                            include dirname(__FILE__) . "/../public/partials/inputs/estatebud-bedroom-select.php";
                            break;
                        case "bathroom_select":
                            include dirname(__FILE__) . "/../public/partials/inputs/estatebud-bathroom-select.php";
                            break;
                        case "property_id_input":
                            include dirname(__FILE__) . "/../public/partials/inputs/estatebud-property-id-input.php";
                            break;
                        case "price_min_input":
                            include dirname(__FILE__) . "/../public/partials/inputs/estatebud-price-min-input.php";
                            break;
                        case "price_max_input":
                            include dirname(__FILE__) . "/../public/partials/inputs/estatebud-price-max-input.php";
                            break;
                        case "title_deed_cb":
                            include dirname(__FILE__) . "/../public/partials/inputs/estatebud-title-deed-check.php";
                            break;
                        case "sea_view_cb":
                            include dirname(__FILE__) . "/../public/partials/inputs/estatebud-sea-view-check.php";
                            break;
                        case "sea_front_cb":
                            include dirname(__FILE__) . "/../public/partials/inputs/estatebud-sea-front-check.php";
                            break;
                        case "swimming_pool_cb":
                            include dirname(__FILE__) . "/../public/partials/inputs/estatebud-swimming-pool-check.php";
                            break;
                        case "close_to_beach_cb":
                            include dirname(__FILE__) . "/../public/partials/inputs/estatebud-closetobeach-check.php";
                            break;
                        case "label_select":
                            include dirname(__FILE__) . "/../public/partials/inputs/estatebud-label-select.php";
                            break;
                    }
                    return ob_get_clean();
                }, $widget_template);

                if($item["item_type"] == "post"){
                    $url = get_permalink($item["redirect_post"]);
                }else{
                    $url = "/".get_page_uri($item["redirect_page"]);
                }

                echo "<form method='GET' action='".$url."'><input type='hidden' name='from' value='searchbox'>".$widget_template."</form>";

                ?>
                <script>
                (function ($) {
                    $(document).ready(function () {
                        jQuery(".widget_estatebud-search-widget").each(function () {
                            window.estatebudStylizeFilterForm($(this));
                        }).addClass("estatebud-filter-form");
                    });
                })(jQuery);
                </script>

                <?php
            }
        }

        echo $args['after_widget'];
    }

    public function form($instance)
    {
        $searchbox = !empty($instance['searchbox']) ? $instance['searchbox'] : esc_html__('', 'estatebud');
        ?>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('searchbox')); ?>"><?php esc_attr_e('Search box:', 'estatebud'); ?></label>
            <select class="widefat" id="<?php echo esc_attr($this->get_field_id('searchbox')); ?>" name="<?php echo esc_attr($this->get_field_name('searchbox')); ?>" >
                <?php
                $items = get_option("estatebud_widget_settings", false);
                if($items){
                    foreach($items as $key => $item){
                        echo "<option value='" . $key . "'" . (($searchbox == $key) ? " selected" : "") . ">" . $item["label"] . "</option>";
                    }
                } ?>
            </select>
        </p>
        <?php
    }

    public function update($new_instance, $old_instance)
    {
        $instance = array();
        $instance['searchbox'] = (!empty($new_instance['searchbox'])) ? strip_tags($new_instance['searchbox']) : '';
        return $instance;
    }
}
$estatebud_search_widget = new Estatebud_Search_Widget();