<?php

function estatebud_get_translation_details($object, $dontUseEnglish = false)
{
    if (!$object) return "";
    $locale = str_replace("_", "-", isset($_GET["lang"]) ? $_GET["lang"] : get_locale());
    if ($locale == 'el') {
        $locale = "el-GR";
    }
    if (property_exists($object, $locale))
        return $object->{$locale};
    else if (property_exists($object, explode("-", $locale)[0]))
        return $object->{explode("-", $locale)[0]};
    else if($dontUseEnglish)
        return false;
    else if (__($object->value, "estatebud") != $object->value)
        return __($object->value, "estatebud");
    else if (property_exists($object, "en-US"))
        return $object->{"en-US"};
    else
        return $object->value;
}

function estatebud_get_property_title($object)
{
    /* Title Block */
    /**
     * Title of properties (i.e. "4 bedroom detached villa") must be translatable in a way to change order.
     * |- (res_rent_short, res_rent_long, res_sale)
     *      String 1:
     *          Singular: "${bedrooms} bedroom ${property_type}"
     *          Plural: "${bedrooms} bedrooms ${property_type}"
     *          (if bedrooms is not set, just echo ${property_type})
     * |- (com_sale, com_rent_long) ${propery_type}
     *      (if propery_type is not set, just echo "Commercial Property" (this can be retrieved from API - should not be translated separately))
     * |- (land) ${property_type}
     *      (if property_type is not set, just echo "Land" (this can be retrieved from API - should not be translated separately))
     */
    $title = false;
    if (property_exists($object, "title")) {
        $title = estatebud_get_translation_details($object->title, true);
    }
    if($title == false){
        if (property_exists($object, "category")) {
            $category = $object->category;
            $property_type = null;
            $title = "";
            if (property_exists($object, "type") && property_exists($object->type, "translations")) {
                $property_type = estatebud_get_translation_details($object->type->translations);
            }
            if ($category == "res_rent_short" || $category == "res_rent_long" || $category == "res_sale") {
                if (property_exists($object, "data") && property_exists($object->data, "bedrooms")) {
                    $title = sprintf(
                        _n(
                            __('%1$d Bedroom %2$s', "estatebud"),
                            __('%1$d Bedrooms %2$s', "estatebud"),
                            $object->data->bedrooms,
                            "estatebud"
                        ), $object->data->bedrooms, $property_type);
                } else {
                    $title = $property_type;
                }
            } else if ($category == "com_sale" || $category == "com_rent_long") {
                $title = $property_type ? $property_type : __("Commercial Property", "estatebud");
            } else if ($category == "land") {
                $title = $property_type ? $property_type : __("Land", "estatebud");
            } else {
                $title = "";
            }
        }else{
            $title = "";
        }
    }
    $title = trim($title);
    return $title != "" ? "<div class='estatebud-property-title'>$title</div>" : "";
}

function estatebud_get_locations_details($object)
{
    $areas = [$object->area1_name, $object->area2_name, $object->area3_name];
    $areas = array_filter($areas);
    if (count($areas) > 1) {
        return implode(", ", array_slice($areas, -2, 2));
    } else if (count($areas)) {
        return $areas[0];
    } else {
        return "";
    }
}

function estatebud_remove_parenthesis($string)
{
    return preg_replace("/\s+\([^)]+\)/i", "", $string);
}

function estatebud_get_currency_details($estatebud_api, $data)
{
    $currency = $estatebud_api->auth_info->currency;

    $type = in_array($data->category, ["res_rent_long", "res_rent_short", "com_rent_long"]) ? "rent" : "price";
    $price = null;
    if ($type == "rent") {
        if (property_exists($data, "rent")) $price = $data->rent;
    } else {
        if (property_exists($data, "price")) $price = $data->price;
    }
    $original = property_exists($data, "originalprice") ? $data->originalprice : null;
    if ($price && property_exists($price, $currency)) {
        $result = "<div>";
        $result .= estatebud_build_price($price->{$currency}, $currency);
        if ($original && property_exists($original, $currency)) {
            $result .= "<br><strike style='margin-right: 0'>" . estatebud_build_price($original->{$currency}, $currency) . "</strike>";
        }
        $result .= "</div>";
        if ($type == "rent") {
            $result .= "<span class='estatebud-property-rent-month'>&nbsp;/&nbsp;" . __("month", "estatebud") . "</span>";
        }
        if (property_exists($price->{$currency}, "vat") && $price->{$currency}->vat == 1) {
            $result .= "<small>" . __("+VAT", "estatebud") . "</small>";
        }
        echo $result;
    } else {
        echo __("On Request", "estatebud");
    }
}

function estatebud_build_price($value, $currency)
{
    $result = "<span class='estatebud-currency-container' data-start-currency='$currency' data-start-value='$value->amount'>";
    if (property_exists($value, "details")) {
        if ($value->details->dir == "left") {
            $result .= $value->details->symbol;
            if ($value->details->space) $result .= " ";
        }
    }
    if (property_exists($value, "amount")) {
        $result .= number_format($value->amount);
        if (property_exists($value, "details")) {
            if ($value->details->dir == "right") {
                if ($value->details->space) $result .= " ";
                $result .= $value->details->symbol;
            }
        }
    }
    return $result . "</span>";
}


function estatebud_get_distance_icon($key)
{
    switch ($key) {
        case "distancetoamenitieskm":
            return "<i class='icon-shopping-basket'></i>";
        case "distancetoairportkm":
            return "<i class='icon-flight'></i>";
        case "distancetoseakm":
            return "<i class='icon-sun'></i>";
        case "distancetoresortkm":
            return "<i class='icon-home'></i>";
        case "distancetoschoolskm":
            return "<i class='icon-graduation-cap'></i>";
        case "distancetotransitkm":
            return "<i class='icon-bus'></i>";
    }
    return "";
}

function estatebud_get_distance_km($km)
{
    if ($km < 1) {
        return round($km * 1000) . " m";
    }
    return $km . " km";
}


function estatebud_property_infos($estatebud_api, $details){    
    if(property_exists($details, "data") && property_exists($details->data,"bedrooms")):?><div class="estatebud-property-info"><i class="icon-bed"></i><b><?php echo __("Bedrooms", "estatebud"); ?>:</b> <?php echo $details->data->bedrooms; ?></div><?php endif; ?>
    <?php if(property_exists($details, "data") && property_exists($details->data,"bathrooms")):?><div class="estatebud-property-info"><i class="icon-bath"></i><b><?php echo __("Bathrooms", "estatebud"); ?>:</b> <?php echo $details->data->bathrooms; ?></div><?php endif; ?>
    <?php if(property_exists($details, "data") && property_exists($details->data,"toilets")):?><div class="estatebud-property-info"><i class="icon-droplet"></i><b><?php echo __("Toilets", "estatebud"); ?>:</b> <?php echo $details->data->toilets; ?></div><?php endif; ?>
    <?php if(property_exists($details, "data") && property_exists($details->data,"constructionyear")):?><div class="estatebud-property-info"><i class="fa fa-calendar"></i><b><?php echo __("Construction Year", "estatebud"); ?>:</b> <?php echo $details->data->constructionyear; ?></div><?php endif; ?>
    <?php if(property_exists($details, "data") && property_exists($details->data,"floors")):?><div class="estatebud-property-info"><i class="fa fa-building"></i><b><?php echo __("Floors", "estatebud"); ?>:</b> <?php echo $details->data->floors; ?></div><?php endif; ?>
    <?php if(property_exists($details, "data") && property_exists($details->data,"floor")):?><div class="estatebud-property-info"><i class="fa fa-external-link-square"></i><b><?php echo __("Floor", "estatebud"); ?>:</b> <?php echo $details->data->floor; ?></div><?php endif; ?>
    <?php if(property_exists($details, "communal_charge") && property_exists($details->communal_charge, $estatebud_api->auth_info->currency)):?><div class="estatebud-property-info"><i class="fa fa-price"></i><b><?php echo __("Communal Charge", "estatebud"); ?>:</b> <?php echo estatebud_build_price($details->communal_charge->{$estatebud_api->auth_info->currency}, $estatebud_api->auth_info->currency); ?></div><?php endif; ?>

    <?php if($estatebud_api->auth_info->measurements == "imperial") :
        estatebud_property_info_area($details, "coveredft2", "icon-resize-full-alt", "ft²");
        estatebud_property_info_area($details, "plotft2", "icon-doc-landscape", "ft²");
        estatebud_property_info_area($details, "unccoveredverandaft2", "icon-move", "ft²");
        estatebud_property_info_area($details, "coveredverandaft2", "icon-move", "ft²");
        estatebud_property_info_area($details, "basementft2", "icon-move", "ft²");
    else:
        estatebud_property_info_area($details, "coveredm2", "icon-resize-full-alt", "m²");
        estatebud_property_info_area($details, "plotm2", "icon-doc-landscape", "m²");
        estatebud_property_info_area($details, "unccoveredverandam2", "icon-move", "m²");
        estatebud_property_info_area($details, "coveredverandam2", "icon-move", "m²");
        estatebud_property_info_area($details, "basementm2", "icon-move", "m²");            
    endif;
}

function estatebud_property_info_area($details, $key, $icon, $suffix){
    if(property_exists($details, "areas") && property_exists($details->areas, $key)){
        echo "<div class=\"estatebud-property-info\"><i class=\"$icon\"></i><b>" . estatebud_get_translation_details($details->areas->{$key}->translations) . ":</b>";
        echo $details->areas->{$key}->value . $suffix . "</div>";
    }
}










